%% 
addpath C:/coyne/engineering/Ifotools/gwincV3
ifo = IFOModel;
src = SourceModel;
flo = 9;
fhi = 5000;
[ss,nn] = gwinc(flo,fhi,ifo,src,2);
ff = nn.Freq;

%% suspension thermal noise in gwinc is obsolete
%% use M Barton's mathematica model output

%mbquadlite2lateral_20090819TM_TN;
QuadLite2Lateral_mark_barton_20120601TMproductionTM_TN;
tvec = sqrt(xvec.^2 + (1e-3*zvec).^2);
tvec = tvec*2;  % 4 masses
nn.SuspThermalB = interp1(fvec,tvec,ff,[],0);
nn.SuspThermalB = nn.SuspThermalB.^2/(4000^2);  % convert to strain


T_PRM = 0.03;
%NOSRM = [25,   0,          1, 0.014, T_PRM, 120/180*pi]; 
NSNS=   [125, 16/180*pi, 0.2, 0.014, T_PRM, 105/180*pi];
ZERODET=[125,  0       , 0.2, 0.014, T_PRM, 113/180*pi];
ZDETLP =[ 25,  0       , 0.2, 0.014, T_PRM, 103/180*pi];

% mode 0
%x = NOSRM;
%ifo.Optics.Quadrature.dc=x(6);
%[s0,n0] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
%n0.Total = nn.ResGas + nn.SuspThermalB + n0.Quantum + nn.Newtonian + ...
%    nn.Seismic + nn.MirrorThermal.Total;
%s0 = int73(ff, n0.Total, ifo, src);

% mode 1a
% mode Low Power
x = ZDETLP;
ifo.Optics.Quadrature.dc=x(6);
[s1a,n1a] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n1a.Total = nn.ResGas + nn.SuspThermalB + n1a.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s1a = int73(ff, n1a.Total, ifo, src);

% mode 1b
% mode Nominal
x = ZERODET;
ifo.Optics.Quadrature.dc=x(6);
[s1b,n1b] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n1b.Total = nn.ResGas + nn.SuspThermalB + n1b.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s1b = int73(ff, n1b.Total, ifo, src);

% mode 2
% mode BNS
x = NSNS;
ifo.Optics.Quadrature.dc=x(6);
[s2,n2] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n2.Total = nn.ResGas + nn.SuspThermalB + n2.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s2 = int73(ff, n2.Total, ifo, src);


%% Plot

hndls=loglog(ff,sqrt(n1a.Total),...
    ff,sqrt(n2.Total),ff,sqrt(n1b.Total));

grid on;

lh = legend('low power','BNS optimized', ...
    'Nominal mode','location','northeast');
axis([flo,fhi,1e-24,1e-21]);

set(hndls(1:(end)),'LineWidth',4);
%set(hndls(2),'color','r','linestyle','--');
%set(hndls(1),'color',0.5*[1 1 1]);
%set(hndls(4),'color','b')
lfont = 16;
set(gca,'fontsize',lfont,'fontweight','normal');
xlabel('Frequency (Hz)','fontsize',lfont);
ylabel('Strain noise (Hz^{-1/2})','fontsize',lfont);
set(lh,'fontsize',14);
set(gca,'children',[hndls(3) hndls(2) hndls(1)]) 
